diff --git a/src/app/(admin)/admin/awards/[id]/page.tsx b/src/app/(admin)/admin/awards/[id]/page.tsx
index 69a524e..65b8dfe 100644
--- a/src/app/(admin)/admin/awards/[id]/page.tsx
+++ b/src/app/(admin)/admin/awards/[id]/page.tsx
@@ -718,7 +718,7 @@ export default function AwardDetailPage({
open={notifyDialogOpen}
onOpenChange={setNotifyDialogOpen}
title="Notify Eligible Projects"
- description={`Send "Selected for ${award.name}" emails to all ${award.eligibleCount} eligible projects.`}
+ description={`Send "Under consideration for ${award.name}" emails to all ${award.eligibleCount} eligible projects.`}
recipientCount={notifyPreview.data?.recipientCount ?? 0}
previewHtml={notifyPreview.data?.html}
isPreviewLoading={notifyPreview.isLoading}
diff --git a/src/server/routers/specialAward.ts b/src/server/routers/specialAward.ts
index 75dfb7b..d1816cb 100644
--- a/src/server/routers/specialAward.ts
+++ b/src/server/routers/specialAward.ts
@@ -1347,7 +1347,7 @@ export const specialAwardRouter = router({
recipient.name || '',
'AWARD_SELECTION_NOTIFICATION',
{
- title: `Selected for ${award.name}`,
+ title: `Under consideration for ${award.name}`,
message: input.customMessage || '',
metadata: {
projectName: e.project.title,
diff --git a/src/lib/email.ts b/src/lib/email.ts
index aee5d38..e007feb 100644
--- a/src/lib/email.ts
+++ b/src/lib/email.ts
@@ -1808,7 +1808,7 @@ Together for a healthier ocean.
}
/**
* Generate "Selected for Special Award" notification email template
*/
export function getAwardSelectionNotificationTemplate(
name: string,
@@ -1819,12 +1819,12 @@ export function getAwardSelectionNotificationTemplate(
): EmailTemplate {
const greeting = name ? `Dear ${name},` : 'Dear Applicant,'
- const celebrationBanner = `
+ const announcementBanner = `
- |
- Congratulations
- Your project has been selected!
+ |
+ Special Award Consideration
+ Your project is under consideration
|
@@ -1840,8 +1840,9 @@ export function getAwardSelectionNotificationTemplate(
const content = `
${sectionTitle(greeting)}
- ${celebrationBanner}
- ${infoBox(`"${projectName}" has been selected for the ${awardName}`, 'success')}
+ ${announcementBanner}
+ ${infoBox(`"${projectName}" has been shortlisted for consideration for the ${awardName}.`, 'info')}
+ ${paragraph('This means your project has caught the attention of our selection committee and is being evaluated for this special recognition. Please note that this is not a final award — further review and evaluation steps may follow.')}
${
escapedMessage
? `${escapedMessage}
`
@@ -1853,16 +1854,18 @@ export function getAwardSelectionNotificationTemplate(
`
return {
- subject: `Your project has been selected for ${awardName}: "${projectName}"`,
+ subject: `Your project is under consideration for ${awardName}: "${projectName}"`,
html: getEmailWrapper(content),
text: `
${greeting}
-Your project has been selected!
+Your project is under consideration for a special award.
Project: ${projectName}
Award: ${awardName}
+Your project has been shortlisted for consideration for the ${awardName}. This means your project has caught the attention of our selection committee and is being evaluated for this special recognition. Please note that this is not a final award — further review and evaluation steps may follow.
+
${customMessage || 'Our team will be in touch with more details about this award and next steps.'}
${accountUrl
@@ -1808,7 +1808,7 @@ Together for a healthier ocean.
}
/**
- * Generate "Selected for Special Award" notification email template
+ * Generate "Under Consideration for Special Award" notification email template
*/
export function getAwardSelectionNotificationTemplate(